@@ -4,14 +4,14 @@ require Exporter;
 use strict;
 use Time::Seconds;
 use Time::Piece;
-use Net::Whois::Raw;
+use Net::Whois::Raw qw($OMIT_MSG $CHECK_FAIL);
 use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA = qw(Exporter);
 @EXPORT = qw(
     expire_date expdate_fmt expdate_int decode_date howmany_days_passed
 );
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 # for Net::Whois::Raw
 $OMIT_MSG = 2;
